@@ -166,7 +166,7 @@ static void testLocalFile(const QString &filename)
 
 static char s_delimiter = ':'; // the alternative is ' '
 
-KUriFilterTest::KUriFilterTest()
+void KUriFilterTest::initTestCase()
 {
     QStandardPaths::setTestModeEnabled(true);
     minicliFilters << QStringLiteral("kshorturifilter") << QStringLiteral("kurisearchfilter") << QStringLiteral("localdomainurifilter");
@@ -175,11 +175,7 @@ KUriFilterTest::KUriFilterTest()
     qputenv("DATAHOME", QFile::encodeName(QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation)));
     datahome = qgetenv("DATAHOME");
     qDebug() << "libpaths" << QCoreApplication::libraryPaths();
-}
 
-void KUriFilterTest::init()
-{
-    qDebug();
     qputenv("KDE_FORK_SLAVES", "yes");   // simpler, for the final cleanup
 
     // Allow testing of the search engine using both delimiters...
@@ -199,8 +195,14 @@ void KUriFilterTest::init()
         cfg.sync();
     }
 
-    // Enable verbosity for debugging
+    // Copy kshorturifilterrc from the src dir so we don't depend on make install / env vars.
     {
+        const QString rcFile = QFINDTESTDATA("../src/urifilters/shorturi/kshorturifilterrc");
+        QVERIFY(!rcFile.isEmpty());
+        const QString localFile = QStandardPaths::writableLocation(QStandardPaths::GenericConfigLocation) + "/kshorturifilterrc";
+        QFile::remove(localFile);
+        QVERIFY(QFile(rcFile).copy(localFile));
+        // Enable verbosity for debugging
         KSharedConfig::openConfig(QStringLiteral("kshorturifilterrc"), KConfig::SimpleConfig)->group(QString()).writeEntry("Verbose", true);
     }
 
@@ -286,9 +288,7 @@ void KUriFilterTest::shortUris_data()
     addRow("ftp://ftp.kde.org", QStringLiteral("ftp://ftp.kde.org"), KUriFilterData::NetProtocol);
     addRow("ftp://username@ftp.kde.org:500", QStringLiteral("ftp://username@ftp.kde.org:500"), KUriFilterData::NetProtocol);
 
-    // ShortURI/LocalDomain filter tests. NOTE: any of these tests can fail
-    // if you have specified your own patterns in kshorturifilterrc. For
-    // examples, see $KDEDIR/share/config/kshorturifilterrc .
+    // ShortURI/LocalDomain filter tests.
     addRow("linuxtoday.com", QStringLiteral("http://linuxtoday.com"), KUriFilterData::NetProtocol);
     addRow("LINUXTODAY.COM", QStringLiteral("http://linuxtoday.com"), KUriFilterData::NetProtocol);
     addRow("kde.org", QStringLiteral("http://kde.org"), KUriFilterData::NetProtocol);
@@ -296,7 +296,8 @@ void KUriFilterTest::shortUris_data()
     addRow("ftp.kde.org:21", QStringLiteral("ftp://ftp.kde.org:21"), KUriFilterData::NetProtocol);
     addRow("cr.yp.to", QStringLiteral("http://cr.yp.to"), KUriFilterData::NetProtocol);
     addRow("www.kde.org:21", QStringLiteral("http://www.kde.org:21"), KUriFilterData::NetProtocol);
-    addRow("foobar.local:8000", QStringLiteral("http://foobar.local:8000"), KUriFilterData::NetProtocol);
+    // This one passes but the DNS lookup takes 5 seconds to fail
+    //addRow("foobar.local:8000", QStringLiteral("http://foobar.local:8000"), KUriFilterData::NetProtocol);
     addRow("foo@bar.com", QStringLiteral("mailto:foo@bar.com"), KUriFilterData::NetProtocol);
     addRow("firstname.lastname@x.foo.bar", QStringLiteral("mailto:firstname.lastname@x.foo.bar"), KUriFilterData::NetProtocol);
     addRow("www.123.foo", QStringLiteral("http://www.123.foo"), KUriFilterData::NetProtocol);
