@@ -40,14 +40,16 @@ static KTcpSocket::SslVersion kSslVersionFromQ(QSsl::SslProtocol protocol)
         return KTcpSocket::SslV3;
     case QSsl::TlsV1_0:
         return KTcpSocket::TlsV1;
+    case QSsl::TlsV1_1:
+        return KTcpSocket::TlsV1_1;
+    case QSsl::TlsV1_2:
+        return KTcpSocket::TlsV1_2;
     case QSsl::AnyProtocol:
         return KTcpSocket::AnySslVersion;
-#if QT_VERSION >= 0x040800
     case QSsl::TlsV1SslV3:
         return KTcpSocket::TlsV1SslV3;
     case QSsl::SecureProtocols:
         return KTcpSocket::SecureProtocols;
-#endif
     default:
         return KTcpSocket::UnknownSslVersion;
     }
@@ -61,10 +63,11 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
     }
     //does it contain any valid protocol?
     KTcpSocket::SslVersions validVersions(KTcpSocket::SslV2 | KTcpSocket::SslV3 | KTcpSocket::TlsV1);
-#if QT_VERSION >= 0x040800
+    validVersions |= KTcpSocket::TlsV1_1;
+    validVersions |= KTcpSocket::TlsV1_2;
     validVersions |= KTcpSocket::TlsV1SslV3;
     validVersions |= KTcpSocket::SecureProtocols;
-#endif
+
     if (!(sslVersion & validVersions)) {
         return QSsl::UnknownProtocol;
     }
@@ -74,14 +77,16 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
         return QSsl::SslV2;
     case KTcpSocket::SslV3:
         return QSsl::SslV3;
-    case KTcpSocket::TlsV1:
+    case KTcpSocket::TlsV1_0:
         return QSsl::TlsV1_0;
-#if QT_VERSION >= 0x040800
+    case KTcpSocket::TlsV1_1:
+        return QSsl::TlsV1_1;
+    case KTcpSocket::TlsV1_2:
+        return QSsl::TlsV1_2;
     case KTcpSocket::TlsV1SslV3:
         return QSsl::TlsV1SslV3;
     case KTcpSocket::SecureProtocols:
         return QSsl::SecureProtocols;
-#endif
 
     default:
         //QSslSocket doesn't really take arbitrary combinations. It's one or all.
@@ -89,6 +94,24 @@ static QSsl::SslProtocol qSslProtocolFromK(KTcpSocket::SslVersion sslVersion)
     }
 }
 
+static QString protocolString(QSsl::SslProtocol protocol)
+{
+    switch (protocol) {
+    case QSsl::SslV2:
+        return QStringLiteral("SSLv2");
+    case QSsl::SslV3:
+        return QStringLiteral("SSLv3");
+    case QSsl::TlsV1_0:
+        return QStringLiteral("TLSv1.0");
+    case QSsl::TlsV1_1:
+        return QStringLiteral("TLSv1.1");
+    case QSsl::TlsV1_2:
+        return QStringLiteral("TLSv1.2");
+    default:
+        return QStringLiteral("Unknown");;
+    }
+}
+
 //cipher class converter KSslCipher -> QSslCipher
 class CipherCc
 {
@@ -702,11 +725,7 @@ void KTcpSocket::setLocalCertificate(const QString &fileName, QSsl::EncodingForm
 
 void KTcpSocket::setVerificationPeerName(const QString &hostName)
 {
-#if QT_VERSION >= 0x040800
     d->sock.setPeerVerifyName(hostName);
-#else
-    Q_UNUSED(hostName);
-#endif
 }
 
 void KTcpSocket::setPrivateKey(const KSslKey &key)
@@ -805,7 +824,12 @@ KTcpSocket::SslVersion KTcpSocket::negotiatedSslVersion() const
     if (!d->sock.isEncrypted()) {
         return UnknownSslVersion;
     }
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
+    return kSslVersionFromQ(d->sock.sessionProtocol());
+#else
     return kSslVersionFromQ(d->sock.protocol());
+#endif
 }
 
 QString KTcpSocket::negotiatedSslVersionName() const
@@ -813,7 +837,12 @@ QString KTcpSocket::negotiatedSslVersionName() const
     if (!d->sock.isEncrypted()) {
         return QString();
     }
+
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
+    return protocolString(d->sock.sessionProtocol());
+#else
     return d->sock.sessionCipher().protocolString();
+#endif
 }
 
 ////////////////////////////// KSslKey
@@ -975,11 +1004,11 @@ QString KSslCipher::digestMethod() const
     //### This is not really backend neutral. It works for OpenSSL and
     //    for RFC compliant names, though.
     if (d->name.endsWith(QLatin1String("SHA"))) {
-        return QString::fromLatin1("SHA-1");
+        return QStringLiteral("SHA-1");
     } else if (d->name.endsWith(QLatin1String("MD5"))) {
-        return QString::fromLatin1("MD5");
+        return QStringLiteral("MD5");
     } else {
-        return QString::fromLatin1("");    // ## probably QString() is enough
+        return QStringLiteral("");    // ## probably QString() is enough
     }
 }
 
